#!/bin/sh
# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# 5630-A36 (C) COPYRIGHT International Business Machines Corp., 1997,2003
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.

# wsadmin launcher

# Usage: wsadmin arguments
#set -x
export WAS_HOME=$WASHOME$
export USER_INSTALL_ROOT=${WAS_HOME}
export JAVA_HOME=$JAVAHOME$
export WAS_LOGGING="-Djava.util.logging.manager=com.ibm.ws.bootstrap.WsLogManager -Djava.util.logging.configureByServer=true"
export PATH=${PATH}:${WAS_HOME}

if [ -f "${JAVA_HOME}/bin/java" ]; then
   export JAVA_EXE="${JAVA_HOME}/bin/java"
else
   export JAVA_EXE="${JAVA_HOME}/jre/bin/java"
fi

# Clean up the common$py.class file
if [ -f ${WAS_HOME}/../scripts/was/common\$py.class ]; then
   rm ${WAS_HOME}/../scripts/was/common\$py.class
fi



# CONSOLE_ENCODING controls the output encoding used for stdout/stderr
#    console - encoding is correct for a console window
#    file    - encoding is the default file encoding for the system
#    <other> - the specified encoding is used.  e.g. Cp1252, Cp850, SJIS
# SET CONSOLE_ENCODING=-Dws.output.encoding=console

# For debugging the utility itself
# export WAS_DEBUG=-Djava.compiler=NONE -Xdebug -Xnoagent -Xrunjdwp:transport=dt_socket,server=y,suspend=y,address=7777

export CLIENTSOAP=-Dcom.ibm.SOAP.ConfigURL=file:"${USER_INSTALL_ROOT}"/properties/soap.client.props
export CLIENTSAS=-Dcom.ibm.CORBA.ConfigURL=file:"${USER_INSTALL_ROOT}"/properties/sas.client.props
export CLIENTSSL=-Dcom.ibm.SSL.ConfigURL=file:"${USER_INSTALL_ROOT}"/properties/ssl.client.props

# you need to change the value to enabled to turn on trace
export wsadminTraceString=-Dcom.ibm.ws.scripting.traceString=com.ibm.*=all=enabled

# the following are wsadmin/scripting property exportup 
export wsadminTraceFile=-Dcom.ibm.ws.scripting.traceFile="${USER_INSTALL_ROOT}"/logs/wsadmin.traceout
export wsadminValOut=-Dcom.ibm.ws.scripting.validationOutput="${USER_INSTALL_ROOT}"/logs/wsadmin.valout


export wsadminHost=-Dcom.ibm.ws.scripting.host=$HOSTNAME$

# to connect to SOAP connector using port 8887 
# you need to make sure the port number is the server port number you want to connect to
export wsadminConnType=-Dcom.ibm.ws.scripting.connectionType=SOAP
# export wsadminPort=-Dcom.ibm.ws.scripting.port=8903
export wsadminPort=-Dcom.ibm.ws.scripting.port=$PORT$

# to connect to RMI connector using port 2815 
# you need to make sure the port number is the server port number you want to connect to
# export wsadminConnType=-Dcom.ibm.ws.scripting.connectionType=RMI
# export wsadminPort=-Dcom.ibm.ws.scripting.port=2815

# to use jacl language or jython language
export wsadminLang=-Dcom.ibm.ws.scripting.defaultLang=jacl
# export wsadminLang=-Dcom.ibm.ws.scripting.defaultLang=jython

export SHELL=com.ibm.ws.scripting.WasxShell

export WSADMIN_PROPERTIES_PROP=
if [ ! -z "$WSADMIN_PROPERTIES" ]; then
  export WSADMIN_PROPERTIES_PROP="-Dcom.ibm.ws.scripting.wsadminprops=${WSADMIN_PROPERTIES}"
fi

export WORKSPACE_PROPERTIES=
if [ ! -z "$CONFIG_CONSISTENCY_CHECK" ]; then
  export WORKSPACE_PROPERTIES="-Dconfig_consistency_check=${CONFIG_CONSISTENCY_CHECK}"
fi
isJavaOption=false
nonJavaOptionCount=1
for option in "$@" ; do
  if [ "$option" = "-javaoption" ] ; then
     isJavaOption=true
  else
     if [ "$isJavaOption" = "true" ] ; then
        javaOption="$javaOption $option"
        isJavaOption=false
     else
        nonJavaOption[$nonJavaOptionCount]="$option"
        nonJavaOptionCount=$((nonJavaOptionCount+1))
     fi
  fi
done

export C_PATH="${C_PATH}:${WAS_HOME}:${WAS_HOME}/properties:${WAS_HOME}/com.ibm.ws.admin.client_6.1.0.jar:${WAS_HOME}/com.ibm.ws.security.crypto_6.1.0.jar:${WAS_HOME}/com.ibm.ws.webservices.thinclient_6.1.0.jar"
# Set java options for performance
PLATFORM=`/bin/uname`
case $PLATFORM in
  AIX)
      PERFJAVAOPTION="-Xms256m -Xmx256m -Xquickstart" ;;
  Linux)
      PERFJAVAOPTION="-Xms256m -Xmx256m -Xj9 -Xquickstart" ;;
  SunOS)
      PERFJAVAOPTION="-Xms256m -Xmx256m -XX:PermSize=40m" ;;
  HP-UX)
      PERFJAVAOPTION="-Xms256m -Xmx256m -XX:PermSize=40m" ;;
  OS/390)
      PERFJAVAOPTION="-Xms256m -Xmx256m" ;;
esac

if [ -z "${JAASSOAP}" ]; then
	  export JAASSOAP=-Djaassoap=off
fi
rc=1
retries=3
for retries in "1 2 3"; do
  "${JAVA_EXE}" \
   ${PERFJAVAOPTION} \
   ${WAS_LOGGING} \
   ${javaoption} \
   ${CONSOLE_ENCODING} \
   ${WAS_DEBUG} \
   "${CLIENTSOAP}" \
   "${JAASSOAP}" \
   "${CLIENTSAS}" \
   "${CLIENTSSL}" \
   ${WSADMIN_PROPERTIES_PROP} \
   ${WORKSPACE_PROPERTIES} \
   "-Duser.install.root=${USER_INSTALL_ROOT}" \
   "-Dwas.install.root=${WAS_HOME}" \
   ${wsadminTraceFile} \
   ${wsadminTraceString} \
   ${wsadminValOut} \
   ${wsadminHost} \
   ${wsadminConnType} \
   ${wsadminPort} \
   ${wsadminLang}  \
   -classpath ${C_PATH}  \
   com.ibm.ws.scripting.WasxShell  \
  "${nonJavaOption[@]}"
  rc=$?
  if [ $rc -le 20 ]; then
	 break
  else 
	echo The WAS action failed, sleeping for 60 seconds and retrying
	sleep 60
  fi
done

exit $rc
